@@ -14,6 +14,9 @@ except ImportError:
 class DBusKeyring(KeyringBackend):
     """KDE KWallet via D-Bus"""
 
+    folder = 'Python'
+    appid = 'Python program'
+
     @properties.ClassProperty
     @classmethod
     def priority(cls):
@@ -24,10 +27,10 @@ class DBusKeyring(KeyringBackend):
         except dbus.DBusException as exc:
             raise RuntimeError(exc.get_dbus_message())
         try:
-            bus.get_object('org.kde.kwalletd', '/modules/kwalletd')
+            bus.get_object('org.kde.kwalletd5', '/modules/kwalletd5')
         except dbus.DBusException:
-            raise RuntimeError('cannot connect to org.kde.kwalletd')
-        return 5.1
+            raise RuntimeError('cannot connect to org.kde.kwalletd5')
+        return 4.9
 
     def __init__(self, *arg, **kw):
         super(DBusKeyring, self).__init__(*arg, **kw)
@@ -38,10 +41,8 @@ class DBusKeyring(KeyringBackend):
             return True
         bus = dbus.SessionBus()
         wId = 0
-        self.folder = 'Python'
-        self.appid = 'Python program'
         try:
-            remote_obj = bus.get_object('org.kde.kwalletd', '/modules/kwalletd')
+            remote_obj = bus.get_object('org.kde.kwalletd5', '/modules/kwalletd5')
             self.iface = dbus.Interface(remote_obj, 'org.kde.KWallet')
             self.handle = self.iface.open(
                         self.iface.networkWallet(), wId, self.appid)
